PyXMake Developer Guide: PyXMake.Tools.Utility.ChangedWorkingDirectory Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
PyXMake.Tools.Utility.ChangedWorkingDirectory Class Reference

Class to create 2to3 compatible pickling dictionary. More...

Inheritance diagram for PyXMake.Tools.Utility.ChangedWorkingDirectory:

## Public Member Functions
| __init__ (self, newPath)
| __enter__ (self)
| __exit__ (self, etype, value, traceback)

## Public Attributes
| newPath = os.path.expanduser(newPath)
| savedPath = os.getcwd()

## Detailed Description

Class to create 2to3 compatible pickling dictionary.

    Context manager for temporarily changing the current working directory.

    @author: Brian M. Hunt

Inherited from built-in object.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.Tools.Utility.ChangedWorkingDirectory.__init__ | ( |  | self,
|  |  | newPath )

Definition at line 299 of file Utility.py.

## Member Function Documentation

## ◆ __enter__()

PyXMake.Tools.Utility.ChangedWorkingDirectory.__enter__ | ( |  | self | ) |

Definition at line 309 of file Utility.py.

## ◆ __exit__()

PyXMake.Tools.Utility.ChangedWorkingDirectory.__exit__ | ( |  | self,
|  |  | etype,
|  |  | value,
|  |  | traceback )

Definition at line 313 of file Utility.py.

## Member Data Documentation

## ◆ newPath

PyXMake.Tools.Utility.ChangedWorkingDirectory.newPath = os.path.expanduser(newPath)

Definition at line 300 of file Utility.py.

## ◆ savedPath

PyXMake.Tools.Utility.ChangedWorkingDirectory.savedPath = os.getcwd()

Definition at line 310 of file Utility.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Tools/Utility.py